@@ -1,11 +1,7 @@
 mod parallel;
 
 use anyhow::{anyhow, bail, Context, Result};
-use argc::{
-    compgen_kind,
-    utils::{escape_shell_words, is_true_value},
-    CompKind, NativeRuntime, Runtime, Shell, COMPGEN_KIND_SYMBOL,
-};
+use argc::{compgen_kind, utils::*, CompKind, NativeRuntime, Runtime, Shell, COMPGEN_KIND_SYMBOL};
 use base64::{engine::general_purpose, Engine as _};
 use path_absolutize::Absolutize;
 use std::{
@@ -65,11 +61,12 @@ fn run() -> Result<i32> {
                     if cmd_args_len < 3 {
                         bail!("No parallel command")
                     }
+                    let bash_options = get_bash_options();
                     let mut code = retrieve_argc_variables().unwrap_or_default();
                     let mut cmds = vec![cmd_args[2].to_string()];
                     cmds.extend(cmd_args[3..].iter().map(|v| escape_shell_words(v)));
                     code.push_str(&cmds.join(" "));
-                    println!("{code}")
+                    println!("{bash_options}{code}")
                 } else {
                     let values = argc::eval(
                         runtime,
@@ -78,10 +75,11 @@ fn run() -> Result<i32> {
                         Some(&args[2]),
                         get_term_width(),
                     )?;
+                    let bash_options = get_bash_options();
                     let dir_vars = export_dir_vars(&args[2]);
                     let code = argc::ArgcValue::to_bash(&values);
                     let export_vars = export_argc_variables(&code);
-                    println!("{dir_vars}{export_vars}{code}")
+                    println!("{bash_options}{dir_vars}{export_vars}{code}")
                 }
             }
             "--argc-run" => {
@@ -315,7 +313,12 @@ fn run_compgen(runtime: NativeRuntime, mut args: Vec<String>) -> Option<()> {
 fn export_argc_variables(code: &str) -> String {
     let mut value = code
         .split('\n')
-        .filter(|line| line.starts_with(argc::utils::VARIABLE_PREFIX))
+        .filter(|line| {
+            line.starts_with(VARIABLE_PREFIX)
+                || line.starts_with("declare ")
+                || *line == BEFORE_HOOK
+                || *line == AFTER_HOOK
+        })
         .map(|v| v.to_string())
         .collect::<Vec<String>>()
         .join(";");
@@ -624,9 +627,16 @@ fn set_permissions<T: AsRef<Path>>(_path: T) -> Result<()> {
     Ok(())
 }
 
+fn get_bash_options() -> String {
+    if is_msys() {
+        "set -o igncr\n".to_string()
+    } else {
+        String::new()
+    }
+}
+
 fn normalize_script_path(path: &str) -> String {
-    if cfg!(windows)
-        && env::var("MSYSTEM").is_ok()
+    if is_msys()
         && path.len() >= 3
         && path.starts_with('/')
         && path.chars().nth(1).map(|v| v.is_ascii_alphabetic()) == Some(true)
@@ -637,3 +647,7 @@ fn normalize_script_path(path: &str) -> String {
     }
     path.to_string()
 }
+
+fn is_msys() -> bool {
+    cfg!(windows) && env::var("MSYSTEM").is_ok()
+}
